==> gimp-1.3.6.tar.bz2: gimp-1.3.6/app/tools/gimphistogramtool.h <==
/* The GIMP -- an image manipulation program
 * Copyright (C) 1995 Spencer Kimball and Peter Mattis
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __GIMP_HISTOGRAM_TOOL_H__
#define __GIMP_HISTOGRAM_TOOL_H__


#include "libgimptool/gimptool.h"


#define HISTOGRAM_WIDTH  256
#define HISTOGRAM_HEIGHT 150


#define GIMP_TYPE_HISTOGRAM_TOOL            (gimp_histogram_tool_get_type ())
#define GIMP_HISTOGRAM_TOOL(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), GIMP_TYPE_HISTOGRAM_TOOL, GimpHistogramTool))
#define GIMP_HISTOGRAM_TOOL_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), GIMP_TYPE_HISTOGRAM_TOOL, GimpHistogramToolClass))
#define GIMP_IS_HISTOGRAM_TOOL(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GIMP_TYPE_HISTOGRAM_TOOL))
#define GIMP_IS_HISTOGRAM_TOOL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GIMP_TYPE_HISTOGRAM_TOOL))
#define GIMP_HISTOGRAM_TOOL_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), GIMP_TYPE_HISTOGRAM_TOOL, GimpHistogramToolClass))


typedef struct _GimpHistogramTool      GimpHistogramTool;
typedef struct _GimpHistogramToolClass GimpHistogramToolClass;

struct _GimpHistogramTool
{
  GimpTool  parent_instance;
};

struct _GimpHistogramToolClass
{
  GimpToolClass  parent_class;
};


void    gimp_histogram_tool_register (GimpToolRegisterCallback  callback,
                                      gpointer                  data);

GType   gimp_histogram_tool_get_type (void) G_GNUC_CONST;


#endif /* __GIMP_HISTOGRAM_TOOL_H__ */

==> gimp-1.3.8.tar.bz2: gimp-1.3.8/app/tools/gimphistogramtool.h <==
/* The GIMP -- an image manipulation program
 * Copyright (C) 1995 Spencer Kimball and Peter Mattis
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __GIMP_HISTOGRAM_TOOL_H__
#define __GIMP_HISTOGRAM_TOOL_H__


#include "gimpimagemaptool.h"


#define HISTOGRAM_WIDTH  256
#define HISTOGRAM_HEIGHT 150


#define GIMP_TYPE_HISTOGRAM_TOOL            (gimp_histogram_tool_get_type ())
#define GIMP_HISTOGRAM_TOOL(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), GIMP_TYPE_HISTOGRAM_TOOL, GimpHistogramTool))
#define GIMP_HISTOGRAM_TOOL_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), GIMP_TYPE_HISTOGRAM_TOOL, GimpHistogramToolClass))
#define GIMP_IS_HISTOGRAM_TOOL(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GIMP_TYPE_HISTOGRAM_TOOL))
#define GIMP_IS_HISTOGRAM_TOOL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GIMP_TYPE_HISTOGRAM_TOOL))
#define GIMP_HISTOGRAM_TOOL_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), GIMP_TYPE_HISTOGRAM_TOOL, GimpHistogramToolClass))


typedef struct _GimpHistogramTool      GimpHistogramTool;
typedef struct _GimpHistogramToolClass GimpHistogramToolClass;

struct _GimpHistogramTool
{
  GimpImageMapTool  parent_instance;
};

struct _GimpHistogramToolClass
{
  GimpImageMapToolClass  parent_class;
};


void    gimp_histogram_tool_register (GimpToolRegisterCallback  callback,
                                      gpointer                  data);

GType   gimp_histogram_tool_get_type (void) G_GNUC_CONST;


#endif /* __GIMP_HISTOGRAM_TOOL_H__ */
